.. cfelpyutils documentation master file, created by
   sphinx-quickstart on Tue Jul 10 12:10:05 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../README.md

Contents
--------

.. toctree::
   :maxdepth: 2

   readme
   cfel_fmt
   guidelines_for_contributors
